<?php

use inc\classes\RsgwsHelper;

defined( 'ABSPATH' ) || exit; // Prevent direct access


global $wpdb;
$rsgws_sync_table = $wpdb->prefix . "rsgws_sepidar_sync";
$results = $wpdb->get_results("SELECT * FROM $rsgws_sync_table");

$user_connection = (new class { use RsgwsHelper; })->get_connection_data();
$software_title = ( !empty( $user_connection ) && isset( $user_connection['software_title'] ) ) ? $user_connection['software_title']: 'sepidar';
?>

<div class="rsgws container p-5">
    <div class="row container">
        <a href="<?php echo IMAGE_LINK . '/rsgws-helpdesk?section=sync-settings&software=' . $software_title; ?>" target="_blank" rel="noreferrer noopener" class="rsgws-helpdesk">
            <i class="tim-icons icon-video-66"></i>
        </a>
        <div class="col-md-12 shadow p-3 mt-3 mb-5 bg-white rounded">
            <a href="<?php echo IMAGE_LINK; ?>" target="_blank" rel="noreferrer noopener"><img class="float-left main-logo" src="<?php echo IMAGE_URL .'/logo.png' ?>" alt="Royal Logo" ></a>
                <h5 class="title"><?php _e('Sync Settings', 'rsgws') ?></h5>
            <hr>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-12">
                    <div class="<?php echo (is_rtl() ? 'float-right' : 'float-left') ?>">
                        <a href="#">
                            <button type="button" data-toggle="modal" data-target="#Modal" data-backdrop="static" data-keyboard="false" class="btn btn-primary btn-sm">
                                <i class="tim-icons icon-simple-add"></i> <?php echo __('Add new', 'rsgws') ?>
                            </button>
                        </a>
                    </div>
                    </div>
                </div>
                <br>
                <div class="dataTables_wrapper dt-bootstrap4 rsgws-multi-table">
                    <div class="row">
                    <div class="col-sm-12">
                        <table id="datatable-sync-settings-main" class="table table-striped dataTable-multi-table dtr-inline collapsed" role="grid" aria-describedby="datatable_info">
                            <thead>
                                <tr role="row">
                                <th class="sorting text-right" tabindex="0" aria-controls="datatable" rowspan="1" colspan="1" aria-label="activate to sort column ascending"><?php echo __('Invoice Type', 'rsgws') ?></th>
                                <th class="sorting_asc text-right" tabindex="0" aria-controls="datatable" rowspan="1" colspan="1" style="width: 260px;" aria-sort="ascending" aria-label="activate to sort column descending"><?php echo __('Title', 'rsgws') ?></th>
                                <th class="sorting_desc_disabled sorting_asc_disabled text-left sorting" tabindex="0" aria-controls="datatable" rowspan="1" colspan="1" style="width: 180px;" aria-label="Actions: activate to sort column ascending"><?php echo __('Actions', 'rsgws') ?></th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if( !empty( $results ) && is_array( $results )) :
                                foreach( $results as $result ) :
                                    switch($result->document_type){
                                        case 'accounting':
                                            $doc_title = __("Accounting", "rsgws");
                                            break;
                                        case 'base_information':
                                            $doc_title = __("Basic Info", "rsgws");
                                            break;
                                        case 'price_note':
                                            $doc_title = __("Price Note", "rsgws");
                                            break;
                                    }

                                    switch($result->sync_type){
                                        case 'static':
                                            $sync_time =  "(" . __(" Hour ", "rsgws") . $result->hour . __(" and ", "rsgws") . $result->minute . __(" minute ", "rsgws") . " )";
                                            $sync_title = __("Static", "rsgws");
                                            break;
                                        case 'periodic':
                                            if($result->per_unit == 'day'){
                                                $per_unit_translate = __('day', 'rsgws');
                                            }elseif($result->per_unit == 'hour'){
                                                $per_unit_translate = __('hour', 'rsgws');
                                            }elseif($result->per_unit == 'minute'){
                                                $per_unit_translate = __('minute', 'rsgws');
                                            }
                                            $sync_time = "(" . __(" Every ", "rsgws") . $result->per_value . " " . $result->per_unit . " )";
                                            $sync_title = __("Periodic", "rsgws");
                                            break;
                                        case 'trigger':
                                            $sync_time = "";
                                            $sync_title = __("Trigger", "rsgws");
                                            break;
                                    }
                                    ?>
                                    <tr role="row" data-sync_id="<?php echo $result->id; ?>">
                                        <td class="text-right">
                                            <?php echo $doc_title; ?>
                                        </td>
                                        <td tabindex="0" class="sorting_1 text-right">
                                            <?php echo $sync_title . " " . $sync_time; ?>
                                        </td>
                                        <td class="text-left">
                                            <a href="#">
                                                <button type="button" class="btn btn-danger btn-link btn-sm remove-sync-item" data-action="remove" title="<?php _e('Remove','rsgws') ?>">
                                                    <i class="tim-icons icon-simple-remove"></i>
                                                </button>
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach;
                                endif; ?>
                            </tbody>
                            <tfoot>
                            </tfoot>
                        </table>
                    </div>
                    </div>
                </div>
            </div>
            <?php wp_nonce_field( 'rsgws-nonce-table', 'rsgws-nonce-table' ) ?>
        </div>
    </div>
</div>

<!-- Modal -->
<div class="modal fade" id="Modal" tabindex="-1" aria-labelledby="ModalLabel" aria-hidden="true">
  <div class="modal-dialog modal-lg">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="ModalLabel"></h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <form method="post" id="sync_setting_form">
            <div class="form-row">
                <div class="form-group col-md-6">
                    <label for="document-type">نوع سند مالی</label>
                    <select name="document_type" id="document-type" class="form-control" autocomplete="off" required>
                        <option value="" <?php if(!empty($results)){ echo !empty($results['document_type']) ? '' : 'selected'; } ?>><?php _e('Choose...', 'rsgws') ?></option>
                        <option value="accounting">اسناد مالی</option>
                        <option value="base_information">اطلاعات پایه</option>
                        <!-- Bug For Price Note  -->
                        <!-- <option value="price_note">اعلامیه قیمت</option> -->
                    </select>
                </div>
            </div>
            <div class="form-row">
                <div class="form-group col-md-6">
                    <label for="sync-type"><?php _e('Sync type', 'rsgws') ?></label>
                    <select name="sync_type" id="sync-type" class="form-control" autocomplete="off" required>
                        <option value="" <?php if(!empty($results)){ echo !empty($results['sync_type']) ? '' : 'selected'; } ?>><?php _e('Choose...', 'rsgws') ?></option>
                        <option value="static"><?php _e('Fixed', 'rsgws') ?></option>
                        <option value="periodic"><?php _e('Periodic', 'rsgws') ?></option>
                        <option value="trigger"><?php _e('On trigger', 'rsgws') ?></option>
                    </select>
                </div>
            </div>
            <div class="form-row">
                <div class="form-group col-md-6 hour">
                    <label for="hour"><?php _e('Hour', 'rsgws') ?></label>
                    <input type="number" name="hour" class="form-control" id="hour" min="0" max="23" step="1" value="" required>
                </div>
                <div class="form-group col-md-6 minute">
                    <label for="minute"><?php _e('Minute', 'rsgws') ?></label>
                    <input type="number" name="minute" class="form-control" id="minute" min="0" max="59" step="1" value="" required>
                </div>
            </div>
            <div class="form-row">
                <div class="form-group col-md-6 per-value">
                    <label for="per-value"><?php _e('Every', 'rsgws') ?></label>
                    <input type="number" name="per_value" class="form-control" min="0" step="1" id="per-value" value="" required>
                </div>
                <div class="form-group col-md-6 per-unit">
                    <label for="per-unit">-</label>
                    <select name="per_unit" id="per-unit" class="form-control" autocomplete="off" required>
                        <option value="" <?php if(!empty($results)){ echo !empty($results['per_unit']) ? '' : 'selected'; } ?>><?php _e('Choose...', 'rsgws') ?></option>
                        <option value="day"><?php _e('Day', 'rsgws') ?></option>
                        <option value="hour"><?php _e('Hour', 'rsgws') ?></option>
                        <option value="minute"><?php _e('Minute', 'rsgws') ?></option>
                    </select>
                </div>
            </div>
            <button name="cancel" class="btn btn-light cancel-sync-settings"><?php _e('Cancel', 'rsgws') ?></button>
            <button name="submit" class="btn btn-success submit-sync-settings"><?php _e('Save', 'rsgws') ?></button>
        </form>
      </div>
    </div>
  </div>
</div>